@@ -3,9 +3,9 @@ Main interface for imagebuilder service type definitions.
 
 Usage::
 
-    from mypy_boto3.imagebuilder.type_defs import CancelImageCreationResponseTypeDef
+    from mypy_boto3.imagebuilder.type_defs import AmiDistributionConfigurationTypeDef
 
-    data: CancelImageCreationResponseTypeDef = {...}
+    data: AmiDistributionConfigurationTypeDef = {...}
 """
 import sys
 from typing import Dict, List
@@ -21,8 +21,33 @@ else:
 
 
 __all__ = (
-    "CancelImageCreationResponseTypeDef",
+    "AmiDistributionConfigurationTypeDef",
+    "AmiTypeDef",
     "ComponentConfigurationTypeDef",
+    "ComponentSummaryTypeDef",
+    "ComponentTypeDef",
+    "ComponentVersionTypeDef",
+    "DistributionConfigurationSummaryTypeDef",
+    "DistributionConfigurationTypeDef",
+    "DistributionTypeDef",
+    "EbsInstanceBlockDeviceSpecificationTypeDef",
+    "ImagePipelineTypeDef",
+    "ImageRecipeSummaryTypeDef",
+    "ImageRecipeTypeDef",
+    "ImageStateTypeDef",
+    "ImageSummaryTypeDef",
+    "ImageTestsConfigurationTypeDef",
+    "ImageTypeDef",
+    "ImageVersionTypeDef",
+    "InfrastructureConfigurationSummaryTypeDef",
+    "InfrastructureConfigurationTypeDef",
+    "InstanceBlockDeviceMappingTypeDef",
+    "LaunchPermissionConfigurationTypeDef",
+    "LoggingTypeDef",
+    "OutputResourcesTypeDef",
+    "S3LogsTypeDef",
+    "ScheduleTypeDef",
+    "CancelImageCreationResponseTypeDef",
     "CreateComponentResponseTypeDef",
     "CreateDistributionConfigurationResponseTypeDef",
     "CreateImagePipelineResponseTypeDef",
@@ -35,50 +60,25 @@ __all__ = (
     "DeleteImageRecipeResponseTypeDef",
     "DeleteImageResponseTypeDef",
     "DeleteInfrastructureConfigurationResponseTypeDef",
-    "LaunchPermissionConfigurationTypeDef",
-    "AmiDistributionConfigurationTypeDef",
-    "DistributionTypeDef",
     "FilterTypeDef",
     "GetComponentPolicyResponseTypeDef",
-    "ComponentTypeDef",
     "GetComponentResponseTypeDef",
-    "DistributionConfigurationTypeDef",
     "GetDistributionConfigurationResponseTypeDef",
-    "ImageTestsConfigurationTypeDef",
-    "ScheduleTypeDef",
-    "ImagePipelineTypeDef",
     "GetImagePipelineResponseTypeDef",
     "GetImagePolicyResponseTypeDef",
     "GetImageRecipePolicyResponseTypeDef",
-    "EbsInstanceBlockDeviceSpecificationTypeDef",
-    "InstanceBlockDeviceMappingTypeDef",
-    "ImageRecipeTypeDef",
     "GetImageRecipeResponseTypeDef",
-    "ImageStateTypeDef",
-    "S3LogsTypeDef",
-    "LoggingTypeDef",
-    "InfrastructureConfigurationTypeDef",
-    "AmiTypeDef",
-    "OutputResourcesTypeDef",
-    "ImageTypeDef",
     "GetImageResponseTypeDef",
     "GetInfrastructureConfigurationResponseTypeDef",
     "ImportComponentResponseTypeDef",
-    "ComponentSummaryTypeDef",
     "ListComponentBuildVersionsResponseTypeDef",
-    "ComponentVersionTypeDef",
     "ListComponentsResponseTypeDef",
-    "DistributionConfigurationSummaryTypeDef",
     "ListDistributionConfigurationsResponseTypeDef",
-    "ImageSummaryTypeDef",
     "ListImageBuildVersionsResponseTypeDef",
     "ListImagePipelineImagesResponseTypeDef",
     "ListImagePipelinesResponseTypeDef",
-    "ImageRecipeSummaryTypeDef",
     "ListImageRecipesResponseTypeDef",
-    "ImageVersionTypeDef",
     "ListImagesResponseTypeDef",
-    "InfrastructureConfigurationSummaryTypeDef",
     "ListInfrastructureConfigurationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PutComponentPolicyResponseTypeDef",
@@ -90,14 +90,358 @@ __all__ = (
     "UpdateInfrastructureConfigurationResponseTypeDef",
 )
 
+AmiDistributionConfigurationTypeDef = TypedDict(
+    "AmiDistributionConfigurationTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "amiTags": Dict[str, str],
+        "launchPermission": "LaunchPermissionConfigurationTypeDef",
+    },
+    total=False,
+)
+
+AmiTypeDef = TypedDict(
+    "AmiTypeDef",
+    {"region": str, "image": str, "name": str, "description": str, "state": "ImageStateTypeDef"},
+    total=False,
+)
+
+ComponentConfigurationTypeDef = TypedDict("ComponentConfigurationTypeDef", {"componentArn": str})
+
+ComponentSummaryTypeDef = TypedDict(
+    "ComponentSummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "version": str,
+        "platform": Literal["Windows", "Linux"],
+        "supportedOsVersions": List[str],
+        "type": Literal["BUILD", "TEST"],
+        "owner": str,
+        "description": str,
+        "changeDescription": str,
+        "dateCreated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ComponentTypeDef = TypedDict(
+    "ComponentTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "version": str,
+        "description": str,
+        "changeDescription": str,
+        "type": Literal["BUILD", "TEST"],
+        "platform": Literal["Windows", "Linux"],
+        "supportedOsVersions": List[str],
+        "owner": str,
+        "data": str,
+        "kmsKeyId": str,
+        "encrypted": bool,
+        "dateCreated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ComponentVersionTypeDef = TypedDict(
+    "ComponentVersionTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "version": str,
+        "description": str,
+        "platform": Literal["Windows", "Linux"],
+        "supportedOsVersions": List[str],
+        "type": Literal["BUILD", "TEST"],
+        "owner": str,
+        "dateCreated": str,
+    },
+    total=False,
+)
+
+DistributionConfigurationSummaryTypeDef = TypedDict(
+    "DistributionConfigurationSummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "description": str,
+        "dateCreated": str,
+        "dateUpdated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+_RequiredDistributionConfigurationTypeDef = TypedDict(
+    "_RequiredDistributionConfigurationTypeDef", {"timeoutMinutes": int}
+)
+_OptionalDistributionConfigurationTypeDef = TypedDict(
+    "_OptionalDistributionConfigurationTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "description": str,
+        "distributions": List["DistributionTypeDef"],
+        "dateCreated": str,
+        "dateUpdated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class DistributionConfigurationTypeDef(
+    _RequiredDistributionConfigurationTypeDef, _OptionalDistributionConfigurationTypeDef
+):
+    pass
+
+
+_RequiredDistributionTypeDef = TypedDict("_RequiredDistributionTypeDef", {"region": str})
+_OptionalDistributionTypeDef = TypedDict(
+    "_OptionalDistributionTypeDef",
+    {
+        "amiDistributionConfiguration": "AmiDistributionConfigurationTypeDef",
+        "licenseConfigurationArns": List[str],
+    },
+    total=False,
+)
+
+
+class DistributionTypeDef(_RequiredDistributionTypeDef, _OptionalDistributionTypeDef):
+    pass
+
+
+EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
+    "EbsInstanceBlockDeviceSpecificationTypeDef",
+    {
+        "encrypted": bool,
+        "deleteOnTermination": bool,
+        "iops": int,
+        "kmsKeyId": str,
+        "snapshotId": str,
+        "volumeSize": int,
+        "volumeType": Literal["standard", "io1", "gp2", "sc1", "st1"],
+    },
+    total=False,
+)
+
+ImagePipelineTypeDef = TypedDict(
+    "ImagePipelineTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "description": str,
+        "platform": Literal["Windows", "Linux"],
+        "enhancedImageMetadataEnabled": bool,
+        "imageRecipeArn": str,
+        "infrastructureConfigurationArn": str,
+        "distributionConfigurationArn": str,
+        "imageTestsConfiguration": "ImageTestsConfigurationTypeDef",
+        "schedule": "ScheduleTypeDef",
+        "status": Literal["DISABLED", "ENABLED"],
+        "dateCreated": str,
+        "dateUpdated": str,
+        "dateLastRun": str,
+        "dateNextRun": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ImageRecipeSummaryTypeDef = TypedDict(
+    "ImageRecipeSummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "platform": Literal["Windows", "Linux"],
+        "owner": str,
+        "parentImage": str,
+        "dateCreated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ImageRecipeTypeDef = TypedDict(
+    "ImageRecipeTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "description": str,
+        "platform": Literal["Windows", "Linux"],
+        "owner": str,
+        "version": str,
+        "components": List["ComponentConfigurationTypeDef"],
+        "parentImage": str,
+        "blockDeviceMappings": List["InstanceBlockDeviceMappingTypeDef"],
+        "dateCreated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ImageStateTypeDef = TypedDict(
+    "ImageStateTypeDef",
+    {
+        "status": Literal[
+            "PENDING",
+            "CREATING",
+            "BUILDING",
+            "TESTING",
+            "DISTRIBUTING",
+            "INTEGRATING",
+            "AVAILABLE",
+            "CANCELLED",
+            "FAILED",
+            "DEPRECATED",
+            "DELETED",
+        ],
+        "reason": str,
+    },
+    total=False,
+)
+
+ImageSummaryTypeDef = TypedDict(
+    "ImageSummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "version": str,
+        "platform": Literal["Windows", "Linux"],
+        "osVersion": str,
+        "state": "ImageStateTypeDef",
+        "owner": str,
+        "dateCreated": str,
+        "outputResources": "OutputResourcesTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ImageTestsConfigurationTypeDef = TypedDict(
+    "ImageTestsConfigurationTypeDef",
+    {"imageTestsEnabled": bool, "timeoutMinutes": int},
+    total=False,
+)
+
+ImageTypeDef = TypedDict(
+    "ImageTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "version": str,
+        "platform": Literal["Windows", "Linux"],
+        "enhancedImageMetadataEnabled": bool,
+        "osVersion": str,
+        "state": "ImageStateTypeDef",
+        "imageRecipe": "ImageRecipeTypeDef",
+        "sourcePipelineName": str,
+        "sourcePipelineArn": str,
+        "infrastructureConfiguration": "InfrastructureConfigurationTypeDef",
+        "distributionConfiguration": "DistributionConfigurationTypeDef",
+        "imageTestsConfiguration": "ImageTestsConfigurationTypeDef",
+        "dateCreated": str,
+        "outputResources": "OutputResourcesTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ImageVersionTypeDef = TypedDict(
+    "ImageVersionTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "version": str,
+        "platform": Literal["Windows", "Linux"],
+        "osVersion": str,
+        "owner": str,
+        "dateCreated": str,
+    },
+    total=False,
+)
+
+InfrastructureConfigurationSummaryTypeDef = TypedDict(
+    "InfrastructureConfigurationSummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "description": str,
+        "dateCreated": str,
+        "dateUpdated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+InfrastructureConfigurationTypeDef = TypedDict(
+    "InfrastructureConfigurationTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "description": str,
+        "instanceTypes": List[str],
+        "instanceProfileName": str,
+        "securityGroupIds": List[str],
+        "subnetId": str,
+        "logging": "LoggingTypeDef",
+        "keyPair": str,
+        "terminateInstanceOnFailure": bool,
+        "snsTopicArn": str,
+        "dateCreated": str,
+        "dateUpdated": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+InstanceBlockDeviceMappingTypeDef = TypedDict(
+    "InstanceBlockDeviceMappingTypeDef",
+    {
+        "deviceName": str,
+        "ebs": "EbsInstanceBlockDeviceSpecificationTypeDef",
+        "virtualName": str,
+        "noDevice": str,
+    },
+    total=False,
+)
+
+LaunchPermissionConfigurationTypeDef = TypedDict(
+    "LaunchPermissionConfigurationTypeDef",
+    {"userIds": List[str], "userGroups": List[str]},
+    total=False,
+)
+
+LoggingTypeDef = TypedDict("LoggingTypeDef", {"s3Logs": "S3LogsTypeDef"}, total=False)
+
+OutputResourcesTypeDef = TypedDict(
+    "OutputResourcesTypeDef", {"amis": List["AmiTypeDef"]}, total=False
+)
+
+S3LogsTypeDef = TypedDict("S3LogsTypeDef", {"s3BucketName": str, "s3KeyPrefix": str}, total=False)
+
+ScheduleTypeDef = TypedDict(
+    "ScheduleTypeDef",
+    {
+        "scheduleExpression": str,
+        "pipelineExecutionStartCondition": Literal[
+            "EXPRESSION_MATCH_ONLY", "EXPRESSION_MATCH_AND_DEPENDENCY_UPDATES_AVAILABLE"
+        ],
+    },
+    total=False,
+)
+
 CancelImageCreationResponseTypeDef = TypedDict(
     "CancelImageCreationResponseTypeDef",
     {"requestId": str, "clientToken": str, "imageBuildVersionArn": str},
     total=False,
 )
 
-ComponentConfigurationTypeDef = TypedDict("ComponentConfigurationTypeDef", {"componentArn": str})
-
 CreateComponentResponseTypeDef = TypedDict(
     "CreateComponentResponseTypeDef",
     {"requestId": str, "clientToken": str, "componentBuildVersionArn": str},
@@ -164,142 +508,25 @@ DeleteInfrastructureConfigurationResponseTypeDef = TypedDict(
     total=False,
 )
 
-LaunchPermissionConfigurationTypeDef = TypedDict(
-    "LaunchPermissionConfigurationTypeDef",
-    {"userIds": List[str], "userGroups": List[str]},
-    total=False,
-)
-
-AmiDistributionConfigurationTypeDef = TypedDict(
-    "AmiDistributionConfigurationTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "amiTags": Dict[str, str],
-        "launchPermission": LaunchPermissionConfigurationTypeDef,
-    },
-    total=False,
-)
-
-_RequiredDistributionTypeDef = TypedDict("_RequiredDistributionTypeDef", {"region": str})
-_OptionalDistributionTypeDef = TypedDict(
-    "_OptionalDistributionTypeDef",
-    {
-        "amiDistributionConfiguration": AmiDistributionConfigurationTypeDef,
-        "licenseConfigurationArns": List[str],
-    },
-    total=False,
-)
-
-
-class DistributionTypeDef(_RequiredDistributionTypeDef, _OptionalDistributionTypeDef):
-    pass
-
-
 FilterTypeDef = TypedDict("FilterTypeDef", {"name": str, "values": List[str]}, total=False)
 
 GetComponentPolicyResponseTypeDef = TypedDict(
     "GetComponentPolicyResponseTypeDef", {"requestId": str, "policy": str}, total=False
 )
 
-ComponentTypeDef = TypedDict(
-    "ComponentTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "version": str,
-        "description": str,
-        "changeDescription": str,
-        "type": Literal["BUILD", "TEST"],
-        "platform": Literal["Windows", "Linux"],
-        "supportedOsVersions": List[str],
-        "owner": str,
-        "data": str,
-        "kmsKeyId": str,
-        "encrypted": bool,
-        "dateCreated": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 GetComponentResponseTypeDef = TypedDict(
-    "GetComponentResponseTypeDef", {"requestId": str, "component": ComponentTypeDef}, total=False
+    "GetComponentResponseTypeDef", {"requestId": str, "component": "ComponentTypeDef"}, total=False
 )
 
-_RequiredDistributionConfigurationTypeDef = TypedDict(
-    "_RequiredDistributionConfigurationTypeDef", {"timeoutMinutes": int}
-)
-_OptionalDistributionConfigurationTypeDef = TypedDict(
-    "_OptionalDistributionConfigurationTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "description": str,
-        "distributions": List[DistributionTypeDef],
-        "dateCreated": str,
-        "dateUpdated": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class DistributionConfigurationTypeDef(
-    _RequiredDistributionConfigurationTypeDef, _OptionalDistributionConfigurationTypeDef
-):
-    pass
-
-
 GetDistributionConfigurationResponseTypeDef = TypedDict(
     "GetDistributionConfigurationResponseTypeDef",
-    {"requestId": str, "distributionConfiguration": DistributionConfigurationTypeDef},
-    total=False,
-)
-
-ImageTestsConfigurationTypeDef = TypedDict(
-    "ImageTestsConfigurationTypeDef",
-    {"imageTestsEnabled": bool, "timeoutMinutes": int},
-    total=False,
-)
-
-ScheduleTypeDef = TypedDict(
-    "ScheduleTypeDef",
-    {
-        "scheduleExpression": str,
-        "pipelineExecutionStartCondition": Literal[
-            "EXPRESSION_MATCH_ONLY", "EXPRESSION_MATCH_AND_DEPENDENCY_UPDATES_AVAILABLE"
-        ],
-    },
-    total=False,
-)
-
-ImagePipelineTypeDef = TypedDict(
-    "ImagePipelineTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "description": str,
-        "platform": Literal["Windows", "Linux"],
-        "enhancedImageMetadataEnabled": bool,
-        "imageRecipeArn": str,
-        "infrastructureConfigurationArn": str,
-        "distributionConfigurationArn": str,
-        "imageTestsConfiguration": ImageTestsConfigurationTypeDef,
-        "schedule": ScheduleTypeDef,
-        "status": Literal["DISABLED", "ENABLED"],
-        "dateCreated": str,
-        "dateUpdated": str,
-        "dateLastRun": str,
-        "dateNextRun": str,
-        "tags": Dict[str, str],
-    },
+    {"requestId": str, "distributionConfiguration": "DistributionConfigurationTypeDef"},
     total=False,
 )
 
 GetImagePipelineResponseTypeDef = TypedDict(
     "GetImagePipelineResponseTypeDef",
-    {"requestId": str, "imagePipeline": ImagePipelineTypeDef},
+    {"requestId": str, "imagePipeline": "ImagePipelineTypeDef"},
     total=False,
 )
 
@@ -311,141 +538,19 @@ GetImageRecipePolicyResponseTypeDef = TypedDict(
     "GetImageRecipePolicyResponseTypeDef", {"requestId": str, "policy": str}, total=False
 )
 
-EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
-    "EbsInstanceBlockDeviceSpecificationTypeDef",
-    {
-        "encrypted": bool,
-        "deleteOnTermination": bool,
-        "iops": int,
-        "kmsKeyId": str,
-        "snapshotId": str,
-        "volumeSize": int,
-        "volumeType": Literal["standard", "io1", "gp2", "sc1", "st1"],
-    },
-    total=False,
-)
-
-InstanceBlockDeviceMappingTypeDef = TypedDict(
-    "InstanceBlockDeviceMappingTypeDef",
-    {
-        "deviceName": str,
-        "ebs": EbsInstanceBlockDeviceSpecificationTypeDef,
-        "virtualName": str,
-        "noDevice": str,
-    },
-    total=False,
-)
-
-ImageRecipeTypeDef = TypedDict(
-    "ImageRecipeTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "description": str,
-        "platform": Literal["Windows", "Linux"],
-        "owner": str,
-        "version": str,
-        "components": List[ComponentConfigurationTypeDef],
-        "parentImage": str,
-        "blockDeviceMappings": List[InstanceBlockDeviceMappingTypeDef],
-        "dateCreated": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 GetImageRecipeResponseTypeDef = TypedDict(
     "GetImageRecipeResponseTypeDef",
-    {"requestId": str, "imageRecipe": ImageRecipeTypeDef},
-    total=False,
-)
-
-ImageStateTypeDef = TypedDict(
-    "ImageStateTypeDef",
-    {
-        "status": Literal[
-            "PENDING",
-            "CREATING",
-            "BUILDING",
-            "TESTING",
-            "DISTRIBUTING",
-            "INTEGRATING",
-            "AVAILABLE",
-            "CANCELLED",
-            "FAILED",
-            "DEPRECATED",
-            "DELETED",
-        ],
-        "reason": str,
-    },
-    total=False,
-)
-
-S3LogsTypeDef = TypedDict("S3LogsTypeDef", {"s3BucketName": str, "s3KeyPrefix": str}, total=False)
-
-LoggingTypeDef = TypedDict("LoggingTypeDef", {"s3Logs": S3LogsTypeDef}, total=False)
-
-InfrastructureConfigurationTypeDef = TypedDict(
-    "InfrastructureConfigurationTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "description": str,
-        "instanceTypes": List[str],
-        "instanceProfileName": str,
-        "securityGroupIds": List[str],
-        "subnetId": str,
-        "logging": LoggingTypeDef,
-        "keyPair": str,
-        "terminateInstanceOnFailure": bool,
-        "snsTopicArn": str,
-        "dateCreated": str,
-        "dateUpdated": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-AmiTypeDef = TypedDict(
-    "AmiTypeDef",
-    {"region": str, "image": str, "name": str, "description": str, "state": ImageStateTypeDef},
-    total=False,
-)
-
-OutputResourcesTypeDef = TypedDict(
-    "OutputResourcesTypeDef", {"amis": List[AmiTypeDef]}, total=False
-)
-
-ImageTypeDef = TypedDict(
-    "ImageTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "version": str,
-        "platform": Literal["Windows", "Linux"],
-        "enhancedImageMetadataEnabled": bool,
-        "osVersion": str,
-        "state": ImageStateTypeDef,
-        "imageRecipe": ImageRecipeTypeDef,
-        "sourcePipelineName": str,
-        "sourcePipelineArn": str,
-        "infrastructureConfiguration": InfrastructureConfigurationTypeDef,
-        "distributionConfiguration": DistributionConfigurationTypeDef,
-        "imageTestsConfiguration": ImageTestsConfigurationTypeDef,
-        "dateCreated": str,
-        "outputResources": OutputResourcesTypeDef,
-        "tags": Dict[str, str],
-    },
+    {"requestId": str, "imageRecipe": "ImageRecipeTypeDef"},
     total=False,
 )
 
 GetImageResponseTypeDef = TypedDict(
-    "GetImageResponseTypeDef", {"requestId": str, "image": ImageTypeDef}, total=False
+    "GetImageResponseTypeDef", {"requestId": str, "image": "ImageTypeDef"}, total=False
 )
 
 GetInfrastructureConfigurationResponseTypeDef = TypedDict(
     "GetInfrastructureConfigurationResponseTypeDef",
-    {"requestId": str, "infrastructureConfiguration": InfrastructureConfigurationTypeDef},
+    {"requestId": str, "infrastructureConfiguration": "InfrastructureConfigurationTypeDef"},
     total=False,
 )
 
@@ -455,62 +560,15 @@ ImportComponentResponseTypeDef = TypedDict(
     total=False,
 )
 
-ComponentSummaryTypeDef = TypedDict(
-    "ComponentSummaryTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "version": str,
-        "platform": Literal["Windows", "Linux"],
-        "supportedOsVersions": List[str],
-        "type": Literal["BUILD", "TEST"],
-        "owner": str,
-        "description": str,
-        "changeDescription": str,
-        "dateCreated": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 ListComponentBuildVersionsResponseTypeDef = TypedDict(
     "ListComponentBuildVersionsResponseTypeDef",
-    {"requestId": str, "componentSummaryList": List[ComponentSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-ComponentVersionTypeDef = TypedDict(
-    "ComponentVersionTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "version": str,
-        "description": str,
-        "platform": Literal["Windows", "Linux"],
-        "supportedOsVersions": List[str],
-        "type": Literal["BUILD", "TEST"],
-        "owner": str,
-        "dateCreated": str,
-    },
+    {"requestId": str, "componentSummaryList": List["ComponentSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListComponentsResponseTypeDef = TypedDict(
     "ListComponentsResponseTypeDef",
-    {"requestId": str, "componentVersionList": List[ComponentVersionTypeDef], "nextToken": str},
-    total=False,
-)
-
-DistributionConfigurationSummaryTypeDef = TypedDict(
-    "DistributionConfigurationSummaryTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "description": str,
-        "dateCreated": str,
-        "dateUpdated": str,
-        "tags": Dict[str, str],
-    },
+    {"requestId": str, "componentVersionList": List["ComponentVersionTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -518,97 +576,43 @@ ListDistributionConfigurationsResponseTypeDef = TypedDict(
     "ListDistributionConfigurationsResponseTypeDef",
     {
         "requestId": str,
-        "distributionConfigurationSummaryList": List[DistributionConfigurationSummaryTypeDef],
+        "distributionConfigurationSummaryList": List["DistributionConfigurationSummaryTypeDef"],
         "nextToken": str,
     },
     total=False,
 )
 
-ImageSummaryTypeDef = TypedDict(
-    "ImageSummaryTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "version": str,
-        "platform": Literal["Windows", "Linux"],
-        "osVersion": str,
-        "state": ImageStateTypeDef,
-        "owner": str,
-        "dateCreated": str,
-        "outputResources": OutputResourcesTypeDef,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 ListImageBuildVersionsResponseTypeDef = TypedDict(
     "ListImageBuildVersionsResponseTypeDef",
-    {"requestId": str, "imageSummaryList": List[ImageSummaryTypeDef], "nextToken": str},
+    {"requestId": str, "imageSummaryList": List["ImageSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListImagePipelineImagesResponseTypeDef = TypedDict(
     "ListImagePipelineImagesResponseTypeDef",
-    {"requestId": str, "imageSummaryList": List[ImageSummaryTypeDef], "nextToken": str},
+    {"requestId": str, "imageSummaryList": List["ImageSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListImagePipelinesResponseTypeDef = TypedDict(
     "ListImagePipelinesResponseTypeDef",
-    {"requestId": str, "imagePipelineList": List[ImagePipelineTypeDef], "nextToken": str},
-    total=False,
-)
-
-ImageRecipeSummaryTypeDef = TypedDict(
-    "ImageRecipeSummaryTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "platform": Literal["Windows", "Linux"],
-        "owner": str,
-        "parentImage": str,
-        "dateCreated": str,
-        "tags": Dict[str, str],
-    },
+    {"requestId": str, "imagePipelineList": List["ImagePipelineTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListImageRecipesResponseTypeDef = TypedDict(
     "ListImageRecipesResponseTypeDef",
-    {"requestId": str, "imageRecipeSummaryList": List[ImageRecipeSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-ImageVersionTypeDef = TypedDict(
-    "ImageVersionTypeDef",
     {
-        "arn": str,
-        "name": str,
-        "version": str,
-        "platform": Literal["Windows", "Linux"],
-        "osVersion": str,
-        "owner": str,
-        "dateCreated": str,
+        "requestId": str,
+        "imageRecipeSummaryList": List["ImageRecipeSummaryTypeDef"],
+        "nextToken": str,
     },
     total=False,
 )
 
 ListImagesResponseTypeDef = TypedDict(
     "ListImagesResponseTypeDef",
-    {"requestId": str, "imageVersionList": List[ImageVersionTypeDef], "nextToken": str},
-    total=False,
-)
-
-InfrastructureConfigurationSummaryTypeDef = TypedDict(
-    "InfrastructureConfigurationSummaryTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "description": str,
-        "dateCreated": str,
-        "dateUpdated": str,
-        "tags": Dict[str, str],
-    },
+    {"requestId": str, "imageVersionList": List["ImageVersionTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -616,7 +620,7 @@ ListInfrastructureConfigurationsResponseTypeDef = TypedDict(
     "ListInfrastructureConfigurationsResponseTypeDef",
     {
         "requestId": str,
-        "infrastructureConfigurationSummaryList": List[InfrastructureConfigurationSummaryTypeDef],
+        "infrastructureConfigurationSummaryList": List["InfrastructureConfigurationSummaryTypeDef"],
         "nextToken": str,
     },
     total=False,
